@@ -289,10 +289,10 @@ class ApiObject(object):
         resp = self.session.get(url, headers=hdr)
         return self.process_result(url, resp)
 
-    def post(self, suffix=None, headers=None, data=None, json=None):
+    def post(self, suffix=None, headers=None, data=None, json=None, files=None):
         url = self.compute_url(suffix)
         hdr = self.prep_headers(headers)
-        resp = self.session.post(url, headers=hdr, data=data, json=json)
+        resp = self.session.post(url, headers=hdr, data=data, json=json, files=files)
         return self.process_result(url, resp)
 
     def put(self, suffix=None, headers=None, data=None, json=None):
@@ -335,8 +335,8 @@ class ApiWrapper(object):
     def get(self, suffix=None, headers=None):
         return self.api.get(suffix, headers=headers)
 
-    def post(self, suffix=None, headers=None, data=None, json=None):
-        return self.api.post(suffix, headers=headers, data=data, json=json)
+    def post(self, suffix=None, headers=None, data=None, json=None, files=None):
+        return self.api.post(suffix, headers=headers, data=data, json=json, files=files)
 
     def put(self, suffix=None, headers=None, data=None, json=None):
         return self.api.put(suffix, headers=headers, data=data, json=json)
